// ignore_for_file: no_leading_underscores_for_local_identifiers

import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/theme/theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

class Accordion extends StatelessWidget {
  final String titleText;
  final TextStyle? titleTextStyle;
  final Widget body;
  final String? iconCollapsed;
  final String? iconExpanded;
  final bool isOpen;
  final VoidCallback onToggle;
  final EdgeInsetsGeometry? titlePadding;
  final BoxBorder? titleBorder;
  final BorderStyle titleBorderStyle;
  final Color titleBorderColor;
  final double titleBorderWidth;
  final double horizontalPadding;
  final double bodyTopPadding;
  final double? bodyBorderWidth;

  const Accordion({
    Key? key,
    required this.titleText,
    this.titleTextStyle,
    required this.body,
    this.iconCollapsed,
    this.iconExpanded,
    required this.isOpen,
    required this.onToggle,
    this.titlePadding,
    this.titleBorder,
    this.titleBorderStyle = BorderStyle.none,
    this.titleBorderColor = Colors.transparent,
    this.titleBorderWidth = 1.0,
    this.horizontalPadding = 0,
    this.bodyTopPadding = 0,
    this.bodyBorderWidth,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    String _expandedIconPath = iconExpanded ?? 'assets/images/signed_out/minus.svg';
    String _collapsedIconPath = iconCollapsed ?? 'assets/images/signed_out/plus.svg';
    return Column(
      mainAxisSize: MainAxisSize.min,
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        InkWell(
          onTap: onToggle,
          child: Container(
            padding: titlePadding ?? EdgeInsets.symmetric(vertical: scale(16), horizontal: scale(horizontalPadding)),
            decoration: BoxDecoration(
              border: titleBorder ??
                  Border.all(
                    color: titleBorderColor,
                    style: titleBorderStyle,
                    width: titleBorderWidth,
                  ),
            ),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Flexible(
                  child: Text(
                    titleText,
                    style: titleTextStyle,
                    overflow: TextOverflow.clip,
                  ),
                ),
                SizedBox(width: scale(8)),
                SvgPicture.asset(
                  isOpen ? _expandedIconPath : _collapsedIconPath,
                  height: scale(20),
                  fit: BoxFit.contain,
                ),
              ],
            ),
          ),
        ),
        AnimatedSize(
          duration: const Duration(milliseconds: 500),
          curve: Curves.easeOutSine,
          child: Container(
            padding: EdgeInsets.only(
              top: scale(bodyTopPadding),
              left: scale(horizontalPadding),
              right: scale(horizontalPadding),
            ),
            decoration: BoxDecoration(
              border: (bodyBorderWidth != null)
                  ? Border(bottom: BorderSide(color: context.theme.appColors.grey200, width: scale(1)))
                  : null,
            ),
            height: isOpen ? null : 0,
            child: body,
          ),
        ),
      ],
    );
  }
}
