// ignore_for_file: no_leading_underscores_for_local_identifiers
import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/theme/theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

// ignore: must_be_immutable
class Button extends StatelessWidget {
  final VoidCallback? onPressed;
  final String label;
  final Color? labelColor;
  final TextStyle? labelStyle;
  final Color? bgColor;
  final Color? borderColor;
  final double? borderWidth;
  final double? fontSize;
  EdgeInsets? padding;
  EdgeInsets? margin;
  final double? borderRadius;
  final double? lineHeight;
  final String? imagePath;
  final double? imageSize;
  final double? imageOffset;
  final Color? imageColor;
  final bool? isUnderline;
  final FontWeight? fontWeight;
  final String? fontFamily;
  final bool? isInactive;
  final VoidCallback? onPressedInactive;
  final Widget? child;
  final double? height;
  final double? letterSpacing;

  Button({
    Key? key,
    this.onPressed,
    required this.label,
    this.labelColor,
    this.labelStyle,
    this.bgColor,
    this.borderColor,
    this.borderWidth,
    this.fontSize,
    this.padding,
    this.margin,
    this.borderRadius,
    this.lineHeight,
    this.imagePath,
    this.imageSize,
    this.imageOffset,
    this.imageColor,
    this.isUnderline,
    this.fontWeight,
    this.fontFamily,
    this.isInactive,
    this.onPressedInactive,
    this.child,
    this.height,
    this.letterSpacing,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final _labelStyle = TextStyle(
      fontSize: scale(fontSize ?? 16),
      color: labelColor ?? context.theme.appColors.white,
      fontWeight: fontWeight ?? FontWeight.w600,
      height: lineHeight ?? 24 / 16,
      letterSpacing: letterSpacing ?? -.4,
    );
    final decoration = BoxDecoration(
      color: bgColor ?? context.theme.appColors.primary,
      border: (borderColor != null) ? Border.all(color: borderColor!, width: scale(borderWidth ?? .6)) : null,
      borderRadius: BorderRadius.circular(scale(borderRadius ?? 8)),
    );
    return InkWell(
      onTap: (isInactive == true) ? onPressedInactive : onPressed,
      child: Container(
        margin: margin ?? EdgeInsets.zero,
        height: height,
        decoration: (isInactive == true) ? decoration.copyWith(color: context.theme.appColors.grey400) : decoration,
        padding: height != null ? EdgeInsets.symmetric(horizontal: scale(24)) : padding ?? EdgeInsets.all(scale(12)),
        alignment: Alignment.center,
        child: (child != null)
            ? child
            : Row(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  (imagePath != null)
                      ? Container(
                          margin: EdgeInsets.only(right: scale(imageOffset ?? 8)),
                          child: SvgPicture.asset(
                            imagePath!,
                            fit: BoxFit.contain,
                            width: scale(imageSize ?? 20),
                            height: scale(imageSize ?? 20),
                            colorFilter: ColorFilter.mode(
                              imageColor ?? labelColor ?? context.theme.appColors.white,
                              BlendMode.srcIn,
                            ),
                          ),
                        )
                      : const SizedBox.shrink(),
                  Container(
                    decoration: (isUnderline == true)
                        ? BoxDecoration(
                            border: Border(
                              bottom: BorderSide(color: labelColor ?? context.theme.appColors.white, width: .7),
                            ),
                          )
                        : null,
                    child: Text(label, style: labelStyle ?? _labelStyle),
                  ),
                ],
              ),
      ),
    );
  }
}
