import 'package:acurr_package/src/theme/theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:get/get.dart' hide ContextExtensionss;
import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/button.dart';
import 'package:provider/provider.dart';

class EmptyScreen extends StatelessWidget {
  final Widget? icon;
  final String? title;
  final String? body;
  final String? buttonLabel;
  final VoidCallback? onPressed;
  final TextStyle? titleStyle;
  final TextStyle? bodyStyle;
  final TextStyle? buttonTextStyle;
  final String? buttonImagePath;
  final String? backgroundImage;
  final Color? buttonColor;
  final double iconHeight;
  final bool showButton;
  final bool hideIcon;
  final bool hideTitle;
  final bool hideBody;

  const EmptyScreen({
    super.key,
    this.icon,
    this.title,
    this.body,
    this.buttonLabel,
    this.onPressed,
    this.titleStyle,
    this.bodyStyle,
    this.buttonTextStyle,
    this.buttonImagePath,
    this.backgroundImage,
    this.buttonColor,
    this.iconHeight = 64.0,
    this.showButton = false,
    this.hideIcon = false,
    this.hideTitle = false,
    this.hideBody = false,
  });

  @override
  Widget build(BuildContext context) {
    String defaultBody = 'Яг одоо танд гэрээ хийсэн даатгалын \nбүтээгдэхүүн алга байна.';

    List<Widget> children = [];
    final titleStyle1 = TextStyle(
      color: context.theme.appColors.grey950,
      fontSize: scale(16),
      fontWeight: FontWeight.w600,
      height: 24 / 16,
      letterSpacing: -.5,
      overflow: TextOverflow.ellipsis,
    );
    final bodyStyle1 = TextStyle(
      color: context.theme.appColors.grey600,
      fontSize: scale(14),
      fontWeight: FontWeight.w400,
      height: 20 / 14,
      letterSpacing: -.5,
      overflow: TextOverflow.clip,
    );
    final buttonStyle1 = titleStyle1.copyWith(color: context.theme.appColors.white);

    if (!hideIcon) {
      children.add(
        icon ??
            SvgPicture.asset(
              'assets/images/contracts/logo.svg',
              height: iconHeight,
              fit: BoxFit.contain,
            ),
      );
      children.add(SizedBox(height: scale(20)));
    }
    if (!hideTitle) {
      children.add(
        Text(title ?? 'Одоогоор хоосон', style: titleStyle ?? titleStyle1),
      );
      children.add(SizedBox(height: scale(8)));
    }
    if (!hideBody) {
      children.add(
        Text(
          body ?? defaultBody,
          style: bodyStyle ?? bodyStyle1,
          textAlign: TextAlign.center,
        ),
      );
      children.add(SizedBox(height: scale(32)));
    }
    if (showButton) {
      children.add(
        SizedBox(
          width: Get.width,
          child: Button(
            borderRadius: scale(8),
            bgColor: buttonColor,
            labelStyle: buttonTextStyle ?? buttonStyle1,
            label: buttonLabel ?? 'Гэрээ байгуулах',
            onPressed: onPressed,
            imagePath: buttonImagePath,
          ),
        ),
      );
    }
    return Container(
      height: Get.height * 0.65,
      child: Stack(
        children: [
          if (context.read<AppTheme>().themeMode != ThemeMode.dark)
            backgroundImage != null
                ? Align(
                    alignment: Alignment.topCenter,
                    child: Image(
                      image: AssetImage(backgroundImage!),
                      fit: BoxFit.fitHeight,
                    ),
                  )
                : Container(color: Colors.white),
          Center(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: children,
            ),
          ),
        ],
      ),
    );
  }
}
