// ignore_for_file: no_leading_underscores_for_local_identifiers

import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/theme/theme.dart';
import 'package:flutter/material.dart';

import 'package:flutter/services.dart';
import 'package:flutter_svg/flutter_svg.dart';

class FormInput extends StatelessWidget {
  final TextEditingController? controller;
  final Function(String) onValueChanged;
  final Function()? onDone;
  final String? label;
  final Color? labelColor;
  final double? labelBottomMargin;
  final Color? bgColor;
  final String? hintText;
  final TextStyle? hintStyle;
  final TextStyle? textStyle;
  final double? lineHeight;
  final Color? inputColor;
  final String? iconUrl;
  final double? iconSize;
  final String? prefixIconUrl;
  final ColorFilter? iconColor;
  final ColorFilter? prefixIconColor;
  final bool? isPassword;
  final bool? isIcon;
  final bool? isPrefixIcon;
  final bool? iconDivider;
  final bool? isObscure;
  final Function()? onObscureChanged;
  final Function()? onIconTap;
  final List<TextInputFormatter>? inputFormatters;
  final TextInputType? keyboardType;
  final bool? showError;
  final String? errorText;
  final TextStyle? errorStyle;
  final TextAlign? errorAlign;
  final double? errorTopMargin;
  final bool? readOnly;
  final String? initialValue;
  final double? letterSpacing;
  final FocusNode? focusNode;
  final TextCapitalization? textCapitalization;
  final EdgeInsets? padding;
  final Widget? customEndWidget;
  final double? customEndWidgetOffset;
  final EdgeInsets? scrollPadding;
  final double? verticalPadding;
  final double? height;
  final bool? isFloatingLabel;
  final bool? isRedChevron;

  const FormInput({
    super.key,
    required this.onValueChanged,
    this.onDone,
    this.controller,
    this.label,
    this.labelColor,
    this.labelBottomMargin,
    this.bgColor,
    this.hintText,
    this.hintStyle,
    this.textStyle,
    this.lineHeight,
    this.inputColor,
    this.iconUrl,
    this.iconSize,
    this.iconColor,
    this.isPrefixIcon,
    this.isPassword,
    this.isIcon,
    this.prefixIconColor,
    this.iconDivider,
    this.isObscure,
    this.onObscureChanged,
    this.onIconTap,
    this.inputFormatters,
    this.keyboardType,
    this.showError,
    this.errorText,
    this.errorStyle,
    this.errorAlign,
    this.errorTopMargin,
    this.readOnly,
    this.initialValue,
    this.letterSpacing,
    this.prefixIconUrl,
    this.focusNode,
    this.textCapitalization,
    this.padding,
    this.customEndWidget,
    this.customEndWidgetOffset,
    this.scrollPadding,
    this.verticalPadding,
    this.height,
    this.isFloatingLabel,
    this.isRedChevron,
  });

  @override
  Widget build(BuildContext context) {
    final labelStyle = TextStyle(
      fontSize: scale(16),
      fontWeight: FontWeight.w400,
      color: labelColor ?? context.theme.appColors.grey500,
      height: 1,
      letterSpacing: -.112,
    );
    final inputStyle = TextStyle(
      fontSize: scale(16),
      color: inputColor ?? context.theme.appColors.grey950,
      fontWeight: FontWeight.w400,
      overflow: TextOverflow.ellipsis,
      letterSpacing: letterSpacing ?? -.128,
      height: lineHeight ?? (24 / 16),
      // height: 19 / 16,
    );
    final _hintStyle = TextStyle(
      fontSize: scale(16),
      color: context.theme.appColors.grey500,
      fontWeight: FontWeight.w400,
      overflow: TextOverflow.ellipsis,
      letterSpacing: letterSpacing ?? -.128,
    );
    final _errorStyle = TextStyle(
      fontSize: scale(12),
      color: context.theme.appColors.primary,
      fontWeight: FontWeight.w400,
      height: 16 / 12,
      letterSpacing: -.128,
      overflow: TextOverflow.ellipsis,
    );
    final inputBorder = OutlineInputBorder(
      borderRadius: BorderRadius.circular(scale(8)),
      borderSide: BorderSide(
        color: (showError == true) ? context.theme.appColors.primary : context.theme.appColors.grey300,
        width: 1,
      ),
    );
    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Stack(
          children: [
            Container(
              height: scale(height ?? 48),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(scale(8)),
                color: bgColor ?? Colors.transparent,
              ),
              child: TextFormField(
                maxLengthEnforcement: MaxLengthEnforcement.truncateAfterCompositionEnds,
                focusNode: focusNode,
                expands: false,
                minLines: null,
                maxLines: 1,
                initialValue: initialValue,
                controller: controller,
                textAlign: TextAlign.start,
                enableSuggestions: false,
                autocorrect: false,
                decoration: InputDecoration(
                  prefixIcon: isPrefixIcon == true
                      ? Container(
                          padding: EdgeInsets.zero,
                          child: IconButton(
                            padding: EdgeInsets.zero,
                            splashColor: Colors.transparent,
                            highlightColor: Colors.transparent,
                            onPressed: onIconTap,
                            icon: SvgPicture.asset(
                              prefixIconUrl ?? 'assets/images/common/chevron_right.svg',
                              height: scale(iconSize ?? 20),
                              fit: BoxFit.contain,
                              colorFilter:
                                  prefixIconColor ?? ColorFilter.mode(context.theme.appColors.grey700, BlendMode.srcIn),
                            ),
                          ),
                        )
                      : null,
                  suffixIcon: (isRedChevron != null)
                      ? Container(
                          decoration: BoxDecoration(
                            border: Border(left: BorderSide(color: context.theme.appColors.grey300, width: 1)),
                            borderRadius: BorderRadius.only(
                              topRight: Radius.circular(scale(8)),
                              bottomRight: Radius.circular(scale(8)),
                            ),
                            color: context.theme.appColors.primary,
                          ),
                          child: IconButton(
                            splashColor: Colors.transparent,
                            highlightColor: Colors.transparent,
                            onPressed: onIconTap,
                            icon: SvgPicture.asset(
                              'assets/images/common/chevron_right.svg',
                              height: scale(24),
                              fit: BoxFit.contain,
                              colorFilter: ColorFilter.mode(context.theme.appColors.white, BlendMode.srcIn),
                            ),
                          ),
                        )
                      : isIcon == true
                          ? Container(
                              decoration: iconDivider == true
                                  ? BoxDecoration(
                                      border: Border(
                                        left: BorderSide(color: context.theme.appColors.grey300, width: 1),
                                      ),
                                    )
                                  : null,
                              child: IconButton(
                                splashColor: Colors.transparent,
                                highlightColor: Colors.transparent,
                                onPressed: onIconTap,
                                icon: SvgPicture.asset(
                                  iconUrl ?? 'assets/images/common/chevron_right.svg',
                                  height: scale(iconSize ?? 20),
                                  fit: BoxFit.contain,
                                  colorFilter:
                                      iconColor ?? ColorFilter.mode(context.theme.appColors.grey700, BlendMode.srcIn),
                                ),
                              ),
                            )
                          : null,
                  border: inputBorder,
                  enabledBorder: inputBorder,
                  focusedBorder: inputBorder,
                  isDense: true,
                  contentPadding: EdgeInsets.symmetric(
                    vertical: scale(verticalPadding ?? 14),
                    horizontal: scale(16),
                  ),
                  hintText: (isFloatingLabel == false) ? hintText : null,
                  labelText: (isFloatingLabel == false) ? null : hintText,
                  labelStyle: _hintStyle,
                  floatingLabelStyle: labelStyle,
                ),
                onChanged: onValueChanged,
                onEditingComplete: onDone ?? () => {},
                style: textStyle ?? inputStyle,
                obscureText: isObscure ?? false,
                obscuringCharacter: '•',
                inputFormatters: inputFormatters ?? [],
                keyboardType: keyboardType,
                readOnly: readOnly ?? false,
                textCapitalization: textCapitalization ?? TextCapitalization.none,
                scrollPadding: scrollPadding ?? EdgeInsets.zero,
              ),
            ),
            Positioned(
              right: scale(customEndWidgetOffset ?? 8),
              child: (isPassword == true)
                  ? InkWell(
                      onTap: onObscureChanged,
                      child: Container(
                        height: scale(height ?? 48),
                        padding: EdgeInsets.all(scale(12)),
                        child: SvgPicture.asset(
                          (isObscure == true) ? 'assets/images/common/eye-off.svg' : 'assets/images/common/eye.svg',
                          height: scale(20),
                          fit: BoxFit.contain,
                          colorFilter: ColorFilter.mode(context.theme.appColors.grey950, BlendMode.srcIn),
                        ),
                      ),
                    )
                  : const SizedBox.shrink(),
            ),
          ],
        ),
        // Error
        (showError == true && errorText != null && errorText != '')
            ? Container(
                width: double.maxFinite,
                padding: EdgeInsets.only(top: scale(errorTopMargin ?? 8)),
                child: Text(
                  errorText!,
                  style: errorStyle ?? _errorStyle,
                  textAlign: errorAlign ?? TextAlign.start,
                ),
              )
            : const SizedBox.shrink(),
      ],
    );
  }
}
