import 'package:acurr_package/src/theme/palette.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:intl/intl.dart';

final moneyFormatter = NumberFormat("#,##0", "mn");

String getErrorMessage(response) {
  var errors = '';
  try {
    for (var i = 0; i < response.data['msgList'].length; i++) {
      errors += (errors == '') ? '' : '\n';
      if (response.data['msgList'][i]['params'] != null) {
        errors += response.data['msgList'][i]['params']['reason'] ?? response.data['msgList'][i]['params']['field'];
      } else {
        errors += response.data['msgList'][i]['text'] ?? response.data['msgList'][i]['code'] ?? '';
      }
    }
  } catch (e) {
    errors = '';
  }
  return errors;
}

String getErrorMessage2(response) {
  var errors = '';
  try {
    for (var i = 0; i < response['msgList'].length; i++) {
      errors += (errors == '') ? '' : '\n';
      if (response['msgList'][i]['params'] != null) {
        errors += response['msgList'][i]['params']['reason'] ?? response['msgList'][i]['params']['field'];
      } else {
        errors += response['msgList'][i]['text'] ?? response['msgList'][i]['code'] ?? '';
      }
    }
  } catch (e) {
    errors = '';
  }
  return errors;
}

String formatValueDouble2Decimal(amount) {
  double value = double.parse(amount.toString());
  String valueStr = value.toString();
  if (valueStr.contains('.')) {
    String fraction = valueStr.split('.')[1];
    if (double.parse(fraction) == 0) {
      return '${moneyFormatter.format(double.parse(valueStr.split('.')[0]))}.00'.replaceAll(',', "'");
    } else {
      fraction = (fraction.length >= 2) ? fraction.substring(0, 2) : fraction;
      fraction = (fraction.length == 1) ? '${fraction}0' : fraction;
      return '${moneyFormatter.format(double.parse(valueStr.split('.')[0]))}.$fraction'.replaceAll(',', "'");
    }
  } else {
    return '${moneyFormatter.format(value)}.00'.replaceAll(',', "'");
  }
}

String formatValueDoubleDecimalOnly(amount) {
  double value = double.parse(amount.toString());
  String valueStr = value.toString();
  if (valueStr.contains('.')) {
    return moneyFormatter.format(double.parse(valueStr.split('.')[0])).replaceAll(',', "'");
  } else {
    return moneyFormatter.format(value).replaceAll(',', "'");
  }
}

String get2CharString(value) {
  if (value.length == 1) {
    return '0$value';
  } else {
    return value;
  }
}

String camelCase(value) {
  if (value != null && value.length > 0) {
    return "${value[0].toUpperCase()}${value.substring(1).toLowerCase()}";
  }
  return '';
}

String registerUpperCase(value) {
  if (value != null && value.length > 0) {
    return "${value[0].toUpperCase()}${value.substring(1).toUpperCase()}";
  }
  return '';
}

DateTime dateFromMilliseconds(int endDate) {
  return DateTime.fromMillisecondsSinceEpoch(endDate);
}

String getProductPath(int id) {
  String path = '';
  switch (id) {
    case 1:
      // Тээврийн хэрэгслийн даатгал
      path = '/product_vehicle';
      break;
    case 2:
      // Жолоочийн хариуцлагын даатгал
      path = '/product_driver';
      break;
    case 3:
      // Амь насны даатгал
      break;
    case 4:
      // Барьцаа хөрөнгийн даатгал
      path = '/product_property';
      break;
    default:
  }
  return path;
}

Color getProductCardColor(int id) {
  if (id == 4) {
    // Барьцаа хөрөнгийн даатгал
    return hexToColor('#108A98');
  }
  return hexToColor('#8E1223');
}

String getDriverProductPath(int id) {
  String path = '';
  switch (id) {
    case 800:
      // Хувь хүний
      path = '/product_driver_individual';
      break;
    case 801:
      // Хуулийн этгээд
      path = '/product_driver_business';
      break;
    case 802:
      // Мэргэшсэн С,Д
      path = '/product_driver_certified';
      break;
    case 803:
      // Дамжин өнгөрөх
      break;
    default:
  }
  return path;
}

Future<RxMap> getRiskFactorItem(_item, {bool? hasController, dynamic value, NumberFormat? formatter}) async {
  String _controllerValue = '';
  _controllerValue = (value != null) ? value.toString() : _controllerValue;
  _controllerValue =
      (value != null && formatter != null) ? formatter.format(double.tryParse(value) ?? 0) : _controllerValue;
  return {
    'id': _item['id'],
    'label': _item['fieldName'],
    'code': _item['fieldCode'],
    'fieldType': _item['fieldType'],
    'maxValue': _item['maxValue'],
    'minValue': _item['minValue'],
    'readonly': _item['readonly'],
    'placeholderValue': _item['placeholderValue'],
    'value': (value != null) ? value : await getRiskFactorItemInitialValue(_item['fieldType']),
    'displayValue': await getRiskFactorItemInitialValue(_item['fieldType']),
    'controller': (hasController == true) ? TextEditingController(text: _controllerValue) : '',
  }.obs;
}

dynamic getRiskFactorItemInitialValue(type, {bool? isMandatory}) async {
  switch (type) {
    case 'BOOLEAN':
      return isMandatory ?? false;
    case 'NUMBER':
      return 0.0;
    case 'STRING':
      return '';
    default:
  }
}

// Duration formatter
extension RestTimeOnDuration on Duration {
  int get inHoursRest => inHours - (inDays * 24);
  int get inMinutesRest => inMinutes - (inHours * 60);
  int get inSecondsRest => inSeconds - (inMinutes * 60);
}

String formatWithHeadingZero(int value) {
  return (value >= 10) ? '$value' : '0$value';
}

String formatDurationToTime(Duration duration, {minSecondsOnly = false}) {
  if (minSecondsOnly) {
    return '${formatWithHeadingZero(duration.inMinutesRest)}:${formatWithHeadingZero(duration.inSecondsRest)}';
  }
  return '${formatWithHeadingZero(duration.inHoursRest)}:${formatWithHeadingZero(duration.inMinutesRest)}:${formatWithHeadingZero(duration.inSecondsRest)}';
}
