// ignore_for_file: no_leading_underscores_for_local_identifiers, avoid_print

import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_animated_dialog/flutter_animated_dialog.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:get/get.dart' hide ContextExtensionss;
import 'package:url_launcher/url_launcher.dart';

import 'package:acurr_package/src/button.dart';
import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/theme/palette.dart';
import 'package:acurr_package/src/theme/theme.dart';

Future<void> launchInBrowser(String url, {String? errString}) async {
  var _uri = Uri.parse(url);
  if (Platform.isAndroid) {
    try {
      await launchUrl(_uri);
    } catch (e) {
      showToast(context: Get.context!, title: 'Амжилтгүй', body: errString ?? null);
    }
  } else {
    if (await canLaunchUrl(_uri)) {
      await launchUrl(_uri);
    } else {
      showToast(context: Get.context!, title: 'Амжилтгүй', body: errString ?? null);
    }
  }
}

showAlertModal(
  BuildContext context, {
  required bool isInfo,
  bool? isSuccess,
  bool? showIcon,
  bool? isCloseIcon = false,
  String? title,
  String? body,
  String? yesText,
  String? noText,
  String? closeText,
  Function? onYes,
  Function? onNo,
  Function? onClose,
  String? imgPath,
  double? imgSize,
  Color? yesColor,
  Color? buttonColor,
  Color? buttonLabelColor,
  TextStyle? titleStyle,
  TextAlign? titleAlign,
  double? iconSpace,
  bool? barrierDismissible,
}) {
  final _titleStyle = TextStyle(
    fontSize: scale(16),
    fontWeight: FontWeight.w600,
    color: context.theme.appColors.grey950,
    height: 24 / 16,
    letterSpacing: -.5,
  );
  final bodyStyle = TextStyle(
    fontSize: scale(14),
    fontWeight: FontWeight.w400,
    color: context.theme.appColors.grey500,
    height: 20 / 14,
    letterSpacing: -.5,
  );
  final btnLabelStyle = TextStyle(
    fontSize: scale(16),
    fontWeight: FontWeight.w600,
    color: context.theme.appColors.grey700,
    height: 24 / 16,
    letterSpacing: -.4,
  );
  return showDialog<void>(
    context: Get.context!,
    barrierDismissible: barrierDismissible ?? false,
    builder: (BuildContext context) {
      return Dialog(
        backgroundColor: Colors.transparent,
        insetPadding: EdgeInsets.symmetric(horizontal: scale(24)),
        child: Stack(
          children: [
            Container(
              width: Get.width - scale(48),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.all(Radius.circular(scale(8))),
                color: context.theme.appColors.background,
              ),
              padding: EdgeInsets.all(scale(32)),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  SizedBox(height: scale(8)),
                  (showIcon == true)
                      ? SvgPicture.asset(
                          (isSuccess == true) ? 'assets/images/common/success.svg' : 'assets/images/common/failed.svg',
                          height: scale(imgSize ?? 96),
                          fit: BoxFit.contain,
                        )
                      : const SizedBox.shrink(),
                  (imgPath != null && imgPath != '')
                      ? SvgPicture.asset(
                          imgPath,
                          height: scale(imgSize ?? 96),
                          fit: BoxFit.contain,
                        )
                      : const SizedBox.shrink(),
                  SizedBox(height: iconSpace ?? scale(16)),
                  Text(
                    title ?? 'Анхааруулга',
                    style: titleStyle ?? _titleStyle,
                    textAlign: titleAlign ?? TextAlign.start,
                  ),
                  (body != null && body != '')
                      ? Container(
                          margin: EdgeInsets.only(top: scale(12)),
                          child: Text(
                            body,
                            style: bodyStyle,
                            textAlign: TextAlign.center,
                          ),
                        )
                      : const SizedBox.shrink(),
                  SizedBox(height: scale(24)),
                  isInfo
                      ? Button(
                          onPressed: () => onClose != null ? onClose() : Navigator.of(context).pop(),
                          label: closeText ?? 'Дуусгах',
                          borderColor: context.theme.appColors.grey300,
                          bgColor: buttonColor ?? context.theme.appColors.background,
                          labelColor: buttonLabelColor ?? context.theme.appColors.grey950,
                        )
                      : Container(
                          decoration: BoxDecoration(
                            color: context.theme.appColors.background,
                            border: Border.all(color: context.theme.appColors.grey200, width: scale(1)),
                            borderRadius: BorderRadius.circular(scale(8)),
                          ),
                          child: IntrinsicHeight(
                            child: Row(
                              children: [
                                Expanded(
                                  child: InkWell(
                                    onTap: () {
                                      onNo != null ? onNo() : Navigator.of(context).pop();
                                    },
                                    child: Padding(
                                      padding: EdgeInsets.symmetric(vertical: scale(12)),
                                      child: Text(
                                        noText ?? 'Үгүй',
                                        style: btnLabelStyle,
                                        textAlign: TextAlign.center,
                                      ),
                                    ),
                                  ),
                                ),
                                VerticalDivider(
                                  width: scale(1),
                                  thickness: scale(1),
                                  color: context.theme.appColors.grey200,
                                ),
                                Expanded(
                                  child: InkWell(
                                    onTap: () {
                                      onYes != null ? onYes() : Navigator.of(context).pop();
                                    },
                                    child: Padding(
                                      padding: EdgeInsets.symmetric(vertical: scale(12)),
                                      child: Text(
                                        yesText ?? 'Тийм',
                                        style:
                                            btnLabelStyle.copyWith(color: yesColor ?? context.theme.appColors.grey700),
                                        textAlign: TextAlign.center,
                                      ),
                                    ),
                                  ),
                                ),
                              ],
                            ),
                          ),
                        ),
                ],
              ),
            ),
            isCloseIcon ?? false
                ? Positioned(
                    top: scale(10),
                    right: scale(10),
                    child: IconButton(
                      onPressed: () => Get.back(),
                      icon: SvgPicture.asset('assets/images/common/close.svg',
                          height: scale(24),
                          fit: BoxFit.contain,
                          colorFilter: ColorFilter.mode(context.theme.appColors.grey950, BlendMode.srcIn)),
                    ),
                  )
                : const SizedBox.shrink(),
          ],
        ),
      );
    },
  );
}

showToast({
  required BuildContext context,
  required String title,
  bool? isSuccess,
  String? body,
  Function? onClose,
}) {
  final titleStyle = TextStyle(
    fontSize: scale(14),
    fontWeight: FontWeight.w600,
    color: context.theme.appColors.primary,
    height: 20 / 14,
    letterSpacing: -.5,
    decoration: TextDecoration.none,
  );
  final titleStyleSuccess = TextStyle(
    fontSize: scale(14),
    fontWeight: FontWeight.w600,
    color: hexToColor('#13BB56'),
    height: 20 / 14,
    letterSpacing: -.5,
    decoration: TextDecoration.none,
  );
  final bodyStyle = TextStyle(
    fontSize: scale(12),
    fontWeight: FontWeight.w400,
    color: context.theme.appColors.grey950,
    height: 16 / 12,
    letterSpacing: -.5,
    decoration: TextDecoration.none,
  );
  showAnimatedDialog(
    context: context,
    barrierDismissible: true,
    alignment: Alignment.topCenter,
    animationType: DialogTransitionType.slideFromTop,
    curve: Curves.fastOutSlowIn,
    duration: const Duration(milliseconds: 300),
    barrierColor: Colors.black.withOpacity(.3),
    builder: (BuildContext context) {
      return Wrap(
        children: [
          Material(
            clipBehavior: Clip.hardEdge,
            child: Container(
              width: Get.width - scale(48),
              margin: EdgeInsets.only(
                top: AppBar().preferredSize.height,
                left: scale(24),
                right: scale(24),
              ),
              decoration: BoxDecoration(
                color: context.theme.appColors.background,
                borderRadius: BorderRadius.circular(scale(8)),
              ),
              child: Container(
                padding: EdgeInsets.all(scale(12)),
                decoration: BoxDecoration(
                  color: (isSuccess == true)
                      ? hexToColor('#13BB56').withOpacity(.06)
                      : context.theme.appColors.primary.withOpacity(.04),
                  border: Border.all(
                    color: (isSuccess == true) ? hexToColor('#13BB56') : context.theme.appColors.primary,
                    width: scale(1),
                  ),
                  borderRadius: BorderRadius.circular(scale(8)),
                ),
                child: Row(
                  crossAxisAlignment: (body != null) ? CrossAxisAlignment.start : CrossAxisAlignment.center,
                  children: [
                    SvgPicture.asset(
                      (isSuccess == true) ? 'assets/images/common/check.svg' : 'assets/images/common/error.svg',
                      width: scale(20),
                      fit: BoxFit.contain,
                    ),
                    SizedBox(width: scale(8)),
                    Expanded(
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Text(title, style: (isSuccess == true) ? titleStyleSuccess : titleStyle),
                          (body != null)
                              ? Container(
                                  margin: EdgeInsets.only(top: scale(4)),
                                  child: Text(body, style: bodyStyle),
                                )
                              : const SizedBox.shrink()
                        ],
                      ),
                    ),
                    InkWell(
                      onTap: () => Navigator.of(context).pop(),
                      child: Padding(
                        padding: (body != null)
                            ? EdgeInsets.only(left: scale(8), bottom: scale(8))
                            : EdgeInsets.all(scale(4)),
                        child: SvgPicture.asset(
                          'assets/images/common/close.svg',
                          width: scale(20),
                          fit: BoxFit.contain,
                          colorFilter: ColorFilter.mode(context.theme.appColors.grey950, BlendMode.srcIn),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          ),
        ],
      );
    },
  );
}

Future<void> showCustomBottomSheet(
  BuildContext context,
  body, {
  String? title,
  double? titleMargin,
  Color? titleColor,
  Function? onClose,
  double? minHeight,
}) async {
  final titleStyle = TextStyle(
    color: titleColor ?? context.theme.appColors.primary,
    fontSize: scale(16),
    fontWeight: FontWeight.w600,
    height: 24 / 16,
    letterSpacing: -.5,
  );
  return showModalBottomSheet<void>(
    context: context,
    isScrollControlled: true,
    shape: const BeveledRectangleBorder(),
    builder: (context) => Container(
      constraints: BoxConstraints(
        minHeight: minHeight ?? Get.height * .4,
        minWidth: double.infinity,
      ),
      padding: EdgeInsets.only(
        top: scale(24),
        left: scale(24),
        right: scale(24),
        bottom: MediaQuery.of(context).viewInsets.bottom,
      ),
      color: context.theme.appColors.background,
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              (title != null && title != '') ? Text(title, style: titleStyle) : const SizedBox.shrink(),
              InkWell(
                onTap: () => (onClose != null) ? onClose() : Navigator.pop(context),
                child: Padding(
                  padding: EdgeInsets.all(scale(10)),
                  child: SvgPicture.asset(
                    'assets/images/common/close.svg',
                    width: scale(20),
                    fit: BoxFit.contain,
                    colorFilter: ColorFilter.mode(context.theme.appColors.grey950, BlendMode.srcIn),
                  ),
                ),
              ),
            ],
          ),
          SizedBox(height: scale(titleMargin ?? 16)),
          body,
          SizedBox(height: scale(24)),
        ],
      ),
    ),
  );
}

printLog(value) {
  print(value);
}
