import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/theme/theme.dart';

// ignore: must_be_immutable
class IconBorderButton extends StatelessWidget {
  final VoidCallback? onPressed;
  final VoidCallback? onPressedInactive;
  final double? height;
  final double? width;
  final Color? bgColor;
  final Color? borderColor;
  final double? borderWidth;
  final double? borderRadius;
  EdgeInsets? padding;
  EdgeInsets? margin;
  final String imagePath;
  final double? imageSize;
  final bool? isInactive;
  final Widget? child;
  final bool? hasIndicator;
  final Color? iconColor;

  IconBorderButton({
    Key? key,
    this.onPressed,
    this.onPressedInactive,
    this.height,
    this.width,
    this.bgColor,
    this.borderColor,
    this.borderWidth,
    this.borderRadius,
    this.padding,
    this.margin,
    required this.imagePath,
    this.imageSize,
    this.isInactive,
    this.child,
    this.hasIndicator,
    this.iconColor,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return InkWell(
      splashColor: Colors.transparent,
      onTap: (isInactive == true) ? onPressedInactive : onPressed,
      child: Container(
        height: height,
        width: width,
        margin: margin ?? EdgeInsets.zero,
        padding: padding ?? EdgeInsets.all(scale(8 - (borderWidth ?? 1))),
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(scale(borderRadius ?? 8)),
          border: Border.all(
            width: scale(borderWidth ?? 1),
            color: borderColor ?? context.theme.appColors.grey300,
          ),
          color: bgColor ?? Colors.transparent,
        ),
        child: Stack(
          children: [
            Container(
              padding: EdgeInsets.all(scale(4)),
              // alignment: Alignment.center,
              child: child ??
                  SvgPicture.asset(
                    imagePath,
                    width: scale(imageSize ?? 20),
                    height: scale(imageSize ?? 20),
                    colorFilter: ColorFilter.mode(iconColor ?? context.theme.appColors.grey950, BlendMode.srcIn),
                  ),
            ),
            (hasIndicator == true)
                ? Positioned(
                    top: 0,
                    right: 0,
                    child: Container(
                      height: scale(8),
                      width: scale(8),
                      decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(scale(20)),
                        border: Border.all(width: scale(2), color: context.theme.appColors.background),
                        color: context.theme.appColors.primary,
                      ),
                    ),
                  )
                : const SizedBox.shrink(),
          ],
        ),
      ),
    );
  }
}
