// ignore_for_file: no_leading_underscores_for_local_identifiers

import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/theme/theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_layout_grid/flutter_layout_grid.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:get/get.dart' hide ContextExtensionss;

class Picker extends StatelessWidget {
  final String? value;
  final String? label;
  final TextStyle? textStyle;
  final bool? showError;
  final String? errorText;
  final String? placeholder;
  final double? minHeight;
  final FocusNode? focusNode;
  final int? numberOfColumn;
  final double? maxHeight;
  final bool? isFloatingLabel;
  // Container
  final BoxDecoration? decoration;
  final EdgeInsets? padding;
  final double? height;
  // Modal
  final List? list;
  final String? title;
  final Function? onSelect;
  final Color? titleColor;

  const Picker({
    super.key,
    this.value,
    this.label,
    this.textStyle,
    this.showError,
    this.placeholder,
    this.errorText,
    this.minHeight,
    this.focusNode,
    this.isFloatingLabel = false,
    this.numberOfColumn,
    this.list,
    this.title,
    this.onSelect,
    this.maxHeight,
    this.decoration,
    this.padding,
    this.height,
    this.titleColor,
  });

  @override
  Widget build(BuildContext context) {
    final inputStyle = TextStyle(
      color: context.theme.appColors.grey950,
      fontSize: scale(16),
      fontWeight: FontWeight.w500,
      height: 24 / 16,
      overflow: TextOverflow.ellipsis,
      letterSpacing: -.5,
    );
    final errorStyle = TextStyle(
      fontSize: scale(14),
      color: context.theme.appColors.primary,
      fontWeight: FontWeight.w400,
      height: 16 / 14,
      overflow: TextOverflow.ellipsis,
    );
    TextStyle _inputStyle = textStyle ?? inputStyle;
    _inputStyle = (value == '' && placeholder != null)
        ? _inputStyle.copyWith(
            color: context.theme.appColors.grey500,
            fontWeight: FontWeight.w400,
          )
        : _inputStyle;
    final floatingLabelStyle = _inputStyle.copyWith(
      color: context.theme.appColors.grey500,
      fontWeight: FontWeight.w400,
    );
    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        InkWell(
          onTap: () => showList(context, list),
          splashColor: Colors.transparent,
          child: Stack(
            clipBehavior: Clip.none,
            children: [
              Container(
                decoration: decoration ??
                    BoxDecoration(
                      borderRadius: BorderRadius.circular(scale(8)),
                      border: Border.all(
                        color: (showError == true) ? context.theme.appColors.primary : context.theme.appColors.grey300,
                        width: scale(1),
                      ),
                    ),
                padding: padding ?? EdgeInsets.symmetric(horizontal: scale(16)),
                height: height ?? scale(56),
                child: Row(
                  children: [
                    Expanded(
                      child: Text(
                        // (value != null && value != '') ? value! : placeholder ?? '',
                        label != '' && label != null ? label! : placeholder ?? '',
                        style: _inputStyle,
                      ),
                    ),
                    SvgPicture.asset(
                      'assets/images/common/chevron_down.svg',
                      width: scale(16),
                      fit: BoxFit.contain,
                    ),
                  ],
                ),
              ),
              isFloatingLabel == true && value != null && value != ''
                  ? Positioned(
                      top: scale(-12),
                      left: scale(16),
                      child: Container(
                        padding: EdgeInsets.symmetric(horizontal: scale(10)),
                        color: context.theme.appColors.background,
                        child: Text(placeholder ?? '', style: floatingLabelStyle),
                      ),
                    )
                  : SizedBox.shrink(),
            ],
          ),
        ),
        // Error
        (showError == true && errorText != null && errorText != '')
            ? Container(
                padding: EdgeInsets.only(top: scale(12)),
                child: Text(errorText!, style: errorStyle),
              )
            : const SizedBox.shrink(),
      ],
    );
  }

  Future<void> showList(BuildContext context, list) async {
    final titleStyle = TextStyle(
      color: titleColor ?? context.theme.appColors.primary,
      fontSize: scale(16),
      fontWeight: FontWeight.w600,
      height: 24 / 16,
      letterSpacing: -.5,
    );
    List<TrackSize> _rowSizes = [];
    for (var i = 0; i < list.length / (numberOfColumn ?? 1); i++) {
      _rowSizes.add(auto);
    }
    List<TrackSize> _columnSizes = [];
    for (var i = 0; i < (numberOfColumn ?? 1); i++) {
      _columnSizes.add(1.fr);
    }
    return showModalBottomSheet<void>(
      context: context,
      isScrollControlled: true,
      shape: const BeveledRectangleBorder(),
      builder: (context) => Container(
        constraints: BoxConstraints(
          minHeight: minHeight ?? Get.height * .4,
          minWidth: double.infinity,
          maxHeight: maxHeight ?? Get.height * .4,
        ),
        padding: EdgeInsets.all(scale(24)),
        color: context.theme.appColors.background,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                (title != null && title != '') ? Text(title!, style: titleStyle) : const SizedBox.shrink(),
                InkWell(
                  onTap: () => Navigator.pop(context),
                  child: Padding(
                    padding: EdgeInsets.all(scale(10)),
                    child: SvgPicture.asset(
                      'assets/images/common/close.svg',
                      width: scale(20),
                      fit: BoxFit.contain,
                      colorFilter: ColorFilter.mode(context.theme.appColors.grey950, BlendMode.srcIn),
                    ),
                  ),
                ),
              ],
            ),
            SizedBox(height: scale(16)),
            Expanded(
              child: SingleChildScrollView(
                child: LayoutGrid(
                  columnGap: scale(8),
                  rowGap: scale(8),
                  columnSizes: _columnSizes,
                  rowSizes: _rowSizes,
                  children: [
                    for (var i = 0; i < list.length; i++) getListItem(list[i], context),
                  ],
                ),
              ),
            ),
            SizedBox(height: scale(24)),
          ],
        ),
      ),
    );
  }

  Widget getListItem(_item, BuildContext context) {
    final itemStyle = TextStyle(
      color: context.theme.appColors.grey950,
      fontSize: scale(16),
      fontWeight: FontWeight.w600,
      height: 24 / 16,
      letterSpacing: -.5,
    );
    double _itemWidth = Get.width - scale(24) / (numberOfColumn ?? 1);
    return InkWell(
      onTap: () {
        Navigator.pop(context);
        onSelect!(_item);
      },
      child: Container(
        width: _itemWidth,
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(scale(12)),
          border: Border.all(
            color: (value == _item['value']) ? context.theme.appColors.primary : context.theme.appColors.grey300,
            width: scale(1),
          ),
        ),
        padding: EdgeInsets.symmetric(vertical: scale(12)),
        alignment: Alignment.center,
        child: Text(
          _item['label'] ?? _item['value'] ?? '',
          style: (value == _item['value']) ? itemStyle.copyWith(color: context.theme.appColors.grey950) : itemStyle,
          textAlign: TextAlign.center,
        ),
      ),
    );
  }
}
