// ignore_for_file: no_leading_underscores_for_local_identifiers

import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/theme/theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_layout_grid/flutter_layout_grid.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:get/get.dart' hide ContextExtensionss;

class PickerCompact extends StatelessWidget {
  final String? value;
  final String? label;
  final TextStyle? textStyle;
  final FocusNode? focusNode;
  final int? numberOfColumn;
  final double? maxHeight;
  // Container
  final BoxDecoration? decoration;
  final EdgeInsets? padding;
  final EdgeInsets? margin;
  final Color? bgColor;
  final Color? titleColor;
  // Modal
  final List list;
  final String? title;
  final Function? onSelect;

  const PickerCompact({
    super.key,
    this.value,
    this.label,
    this.textStyle,
    this.focusNode,
    this.numberOfColumn,
    required this.list,
    this.title,
    this.onSelect,
    this.maxHeight,
    this.decoration,
    this.padding,
    this.margin,
    this.bgColor,
    this.titleColor,
  });

  @override
  Widget build(BuildContext context) {
    final inputStyle = TextStyle(
      color: context.theme.appColors.grey950,
      fontSize: scale(12),
      fontWeight: FontWeight.w500,
      height: 16 / 12,
      letterSpacing: -.5,
    );
    return InkWell(
      onTap: () => showList(context, list),
      splashColor: Colors.transparent,
      child: Container(
        decoration: decoration ??
            BoxDecoration(
              borderRadius: BorderRadius.circular(scale(8)),
              color: bgColor ?? context.theme.appColors.grey100,
            ),
        padding: padding ?? EdgeInsets.symmetric(vertical: scale(10), horizontal: scale(16)),
        margin: margin ?? EdgeInsets.zero,
        child: Row(
          children: [
            Text(label ?? '', style: textStyle ?? inputStyle),
            SizedBox(width: scale(8)),
            SvgPicture.asset(
              'assets/images/common/chevron_down.svg',
              width: scale(12),
              fit: BoxFit.contain,
            ),
          ],
        ),
      ),
    );
  }

  Future<void> showList(BuildContext context, list) async {
    final titleStyle = TextStyle(
      color: titleColor ?? context.theme.appColors.primary,
      fontSize: scale(16),
      fontWeight: FontWeight.w600,
      height: 24 / 16,
      letterSpacing: -.5,
    );
    List<TrackSize> _rowSizes = [];
    for (var i = 0; i < list.length / (numberOfColumn ?? 1); i++) {
      _rowSizes.add(auto);
    }
    List<TrackSize> _columnSizes = [];
    for (var i = 0; i < (numberOfColumn ?? 1); i++) {
      _columnSizes.add(1.fr);
    }
    return showModalBottomSheet<void>(
      context: context,
      isScrollControlled: true,
      shape: const BeveledRectangleBorder(),
      builder: (context) => Container(
        constraints: BoxConstraints(
          minHeight: Get.height * .4,
          minWidth: double.infinity,
          maxHeight: maxHeight ?? Get.height * .4,
        ),
        padding: EdgeInsets.all(scale(24)),
        color: context.theme.appColors.background,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                (title != null && title != '') ? Text(title!, style: titleStyle) : const SizedBox.shrink(),
                InkWell(
                  onTap: () => Navigator.pop(context),
                  child: Padding(
                    padding: EdgeInsets.all(scale(10)),
                    child: SvgPicture.asset(
                      'assets/images/common/close.svg',
                      width: scale(20),
                      fit: BoxFit.contain,
                    ),
                  ),
                ),
              ],
            ),
            SizedBox(height: scale(16)),
            Expanded(
              child: SingleChildScrollView(
                child: LayoutGrid(
                  columnGap: scale(8),
                  rowGap: scale(8),
                  columnSizes: _columnSizes,
                  rowSizes: _rowSizes,
                  children: [
                    for (var i = 0; i < list.length; i++) getListItem(list[i], context),
                  ],
                ),
              ),
            ),
            SizedBox(height: scale(24)),
          ],
        ),
      ),
    );
  }

  Widget getListItem(_item, BuildContext context) {
    final itemStyle = TextStyle(
      color: context.theme.appColors.grey950,
      fontSize: scale(16),
      fontWeight: FontWeight.w600,
      height: 24 / 16,
      letterSpacing: -.5,
    );
    double _itemWidth = Get.width - scale(24) / (numberOfColumn ?? 1);
    return InkWell(
      onTap: () {
        Navigator.pop(context);
        onSelect!(_item);
      },
      child: Container(
        width: _itemWidth,
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(scale(12)),
          border: Border.all(
            color: (value == _item['value']) ? context.theme.appColors.primary : context.theme.appColors.grey300,
            width: scale(1),
          ),
        ),
        padding: EdgeInsets.symmetric(vertical: scale(12)),
        alignment: Alignment.center,
        child: Text(
          _item['label'] ?? _item['value'] ?? '',
          style: (value == _item['value']) ? itemStyle.copyWith(color: context.theme.appColors.grey950) : itemStyle,
          textAlign: TextAlign.center,
        ),
      ),
    );
  }
}
