import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/button.dart';
import 'package:flutter/material.dart';

import 'package:acurr_package/src/theme/theme.dart';

class ResponseModal extends ModalRoute<void> {
  final VoidCallback? onDismiss;
  final VoidCallback? onSuccess;
  final bool isSuccess;
  final String title;
  final String? body;
  final String? label;

  ResponseModal({
    this.onDismiss,
    this.onSuccess,
    required this.isSuccess,
    required this.title,
    this.body,
    this.label,
  });

  @override
  Color get barrierColor => Colors.black.withOpacity(0.5);

  @override
  bool get barrierDismissible => false;

  @override
  String? get barrierLabel => null;

  @override
  Widget buildPage(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation) {
    return Scaffold(
      backgroundColor: context.theme.appColors.background,
      // appBar: appBar(
      //     color: AppColor.white,
      //     onBack: () {
      //       onDismiss!();
      //     }),
      body: SafeArea(
        child: _buildOverlayContent(context),
      ),
    );
  }

  Widget _buildOverlayContent(BuildContext context) {
    final titleStyle = TextStyle(
      fontSize: scale(24),
      color: context.theme.appColors.background,
      fontWeight: FontWeight.w500,
      height: 28 / 24,
    );
    final bodyStyle = TextStyle(
      fontSize: scale(16),
      color: context.theme.appColors.background,
      fontWeight: FontWeight.w400,
      height: 20 / 16,
    );
    return Container(
      color: context.theme.appColors.background,
      alignment: Alignment.center,
      padding: EdgeInsets.all(scale(16)),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Expanded(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Image(
                  fit: BoxFit.cover,
                  width: scale(108),
                  height: scale(108),
                  gaplessPlayback: true,
                  image:
                      AssetImage(isSuccess ? 'assets/images/common/success.png' : 'assets/images/common/unsuccess.png'),
                ),
                SizedBox(height: scale(40)),
                Text(title, style: titleStyle, textAlign: TextAlign.center),
                (body != null)
                    ? Container(
                        margin: EdgeInsets.only(
                          top: scale(20),
                          left: scale(20),
                          right: scale(20),
                        ),
                        child: Text(
                          body!,
                          style: bodyStyle,
                          textAlign: TextAlign.center,
                        ),
                      )
                    : SizedBox(),
                SizedBox(height: scale(40)),
              ],
            ),
          ),
          Button(onPressed: onSuccess, label: label ?? 'Хаах'),
        ],
      ),
    );
  }

  @override
  bool get maintainState => true;

  @override
  bool get opaque => false;

  @override
  Duration get transitionDuration => Duration(milliseconds: 500);
}
