import 'dart:io';

import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/theme/theme.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class CustomSwitch extends StatelessWidget {
  final bool value;
  final Function(bool)? onChanged;
  final String? label;
  final TextStyle? style;
  final EdgeInsets? padding;
  final CrossAxisAlignment? crossAxisAlignment;
  final Alignment? iconAlignment;
  final double? gap;

  const CustomSwitch({
    Key? key,
    required this.value,
    this.onChanged,
    this.label,
    this.style,
    this.padding,
    this.crossAxisAlignment,
    this.iconAlignment,
    this.gap,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final labelStyle = TextStyle(
      fontSize: scale(14),
      fontWeight: FontWeight.w500,
      color: context.theme.appColors.grey950,
      height: 20 / 14,
      letterSpacing: -.4,
    );
    return Padding(
      padding: padding ?? EdgeInsets.symmetric(vertical: scale(14)),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: crossAxisAlignment ?? CrossAxisAlignment.center,
        children: [
          SizedBox(
            width: scale(36),
            height: scale(24),
            child: Transform.scale(
              transformHitTests: false,
              scale: .65,
              // scale: 1,
              alignment: iconAlignment ?? Alignment.centerRight,
              child: Platform.isIOS
                  ? CupertinoSwitch(
                      value: value,
                      onChanged: onChanged,
                      activeColor: context.theme.appColors.primary,
                    )
                  : Switch(
                      value: value,
                      onChanged: onChanged,
                      activeColor: context.theme.appColors.primary,
                    ),
            ),
          ),
          SizedBox(width: scale(gap ?? 8)),
          (label != null) ? Expanded(child: Text(label!, style: style ?? labelStyle)) : const SizedBox.shrink(),
        ],
      ),
    );
  }
}
