import 'package:flutter/material.dart';

import 'package:acurr_package/src/common/helper.dart';
import 'package:acurr_package/src/theme/theme.dart';

class CustomTabBar extends StatelessWidget {
  final TabController tabController;
  final List<String> tabLabels;

  const CustomTabBar({Key? key, required this.tabController, required this.tabLabels}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.center,
      children: [
        TabBar(
          controller: tabController,
          indicator: const BoxDecoration(
            border: Border(
              bottom: BorderSide(
                color: Colors.transparent,
              ),
            ),
          ),
          labelColor: context.theme.appColors.primary,
          unselectedLabelColor: context.theme.appColors.grey950,
          tabs: List.generate(
            tabLabels.length,
            (index) => _getTab(tabLabels[index], context, index),
          ),
        ),
        Positioned(
          top: 0,
          bottom: 0,
          left: MediaQuery.of(context).size.width / scale(2.1),
          child: VerticalDivider(
            color: context.theme.appColors.grey200,
            width: scale(20),
          ),
        ),
      ],
    );
  }

  Widget _getTab(String label, BuildContext context, int tabIndex) {
    final tabStyle = TextStyle(
      fontSize: scale(14),
      fontWeight: FontWeight.w600,
      letterSpacing: -0.112,
      height: 20 / 14,
    );
    return Tab(
      child: InkWell(
        onTap: () {
          if (tabController.index != tabIndex) {
            tabController.animateTo(tabIndex);
          }
        },
        child: Container(
          padding: EdgeInsets.symmetric(horizontal: scale(8), vertical: scale(14)),
          alignment: Alignment.center,
          child: Text(label, style: tabStyle),
        ),
      ),
    );
  }
}
