import 'package:flutter/material.dart';

Color hexToColor(String hex) {
  assert(RegExp(r'^#([0-9a-fA-F]{6})|([0-9a-fA-F]{8})$').hasMatch(hex), 'hex color must be #rrggbb or #rrggbbaa');
  return Color(
    int.parse(hex.substring(1), radix: 16) + (hex.length == 7 ? 0xff000000 : 0x00000000),
  );
}

abstract class AppPalette {
  static Color primary = hexToColor('#FF0E20');
  static Color cursorLight = hexToColor('#6C737F');
  static Color cursorDark = hexToColor('#AAAAAA');
  // White
  static const white = Color(0xFFFFFFFF);

  // Grey
  static GreyColors grey = GreyColors();

  // Gradient
  static Color barGradient = hexToColor('#384250');
  static Color barGradientDark = hexToColor('#424242');
}

/// Alternative way to group colors in the palette.
///
/// The downside is that you won't be able
/// to use them as constructor default values,
/// because they are not constants.
///
/// Usage example: `AppPalette.grey.grey50`.
class GreyColors {
  GreyColors();
  final grey25 = hexToColor('#FCFCFD');
  final grey25Dark = hexToColor('#141414');
  final grey50 = hexToColor('#F9FAFB');
  final grey50Dark = hexToColor('#292929');
  final grey100 = hexToColor('#F3F4F6');
  final grey100Dark = hexToColor('#292929');
  final grey200 = hexToColor('#E5E7EB');
  final grey200Dark = hexToColor('#424242');
  final grey300 = hexToColor('#D2D6DB');
  final grey300Dark = hexToColor('#525252');
  final grey400 = hexToColor('#9DA4AE');
  final grey400Dark = hexToColor('#737373');
  final grey500 = hexToColor('#6C737F');
  final grey500Dark = hexToColor('#AAAAAA');
  final grey600 = hexToColor('#4D5761');
  final grey600Dark = hexToColor('#D6D6D6');
  final grey700 = hexToColor('#384250');
  final grey700Dark = hexToColor('#E5E5E5');
  final grey800 = hexToColor('#1F2A37');
  final grey800Dark = hexToColor('#F5F5F5');
  final grey900 = hexToColor('#111927');
  final grey900Dark = hexToColor('#FCFCFC');
  final grey950 = hexToColor('#0D121C');
  final grey950Dark = hexToColor('#FFFFFF');
  final whiteDark = hexToColor('#0F0F0F');
}
