import 'package:flutter/material.dart';
import 'package:acurr_package/src/theme/colors_extension.dart';
import 'package:acurr_package/src/theme/palette.dart';
import 'package:acurr_package/src/theme/text_extension.dart';
import 'package:acurr_package/src/theme/typegraphy.dart';

class AppTheme with ChangeNotifier {
  ThemeMode _themeMode = ThemeMode.system;
  ThemeMode get themeMode => _themeMode;

  set themeMode(ThemeMode themeMode) {
    _themeMode = themeMode;
    notifyListeners();
  }

  // Light theme
  static final light = () {
    // final defaultTheme = ThemeData.light(useMaterial3: true);
    final defaultTheme = ThemeData(
      brightness: Brightness.light,
      useMaterial3: true,
      fontFamily: 'SfPro',
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      canvasColor: Colors.transparent,
      textSelectionTheme: TextSelectionThemeData(
        cursorColor: AppPalette.cursorLight,
      ),
    );
    return defaultTheme.copyWith(
      textTheme: defaultTheme.textTheme.copyWith(
        // Default text style for Text widget.
        bodyMedium: AppTypography.body1.copyWith(color: Colors.black),
        // fontFamily: 'SfPro',
      ),
      extensions: [
        _lightAppColors,
        _lightTextTheme,
      ],
    );
  }();
  static final _lightAppColors = AppColorsExtension(
    primary: AppPalette.primary,
    onPrimary: AppPalette.white,
    secondary: const Color(0xff03dac6),
    onSecondary: Colors.black,
    error: const Color(0xffb00020),
    onError: Colors.white,
    background: AppPalette.white,
    onBackground: Colors.black,
    surface: Colors.white,
    onSurface: Colors.black,
    primaryLight: hexToColor('#FFd7DA'),
    white: AppPalette.white,
    barGradient: AppPalette.barGradient,
    // Grey
    grey25: AppPalette.grey.grey25,
    grey50: AppPalette.grey.grey50,
    grey100: AppPalette.grey.grey100,
    grey200: AppPalette.grey.grey200,
    grey300: AppPalette.grey.grey300,
    grey400: AppPalette.grey.grey400,
    grey500: AppPalette.grey.grey500,
    grey600: AppPalette.grey.grey600,
    grey700: AppPalette.grey.grey700,
    grey800: AppPalette.grey.grey800,
    grey900: AppPalette.grey.grey900,
    grey950: AppPalette.grey.grey950,
    grey951: AppPalette.grey.grey950,
  );

  static final _lightTextTheme = SimpleAppTextThemeExtension(
    body1: AppTypography.body1.copyWith(color: _lightAppColors.onBackground),
    h1: AppTypography.h1.copyWith(color: Colors.black),
  );

  // Dark theme
  static final dark = () {
    // final defaultTheme = ThemeData.dark();
    final defaultTheme = ThemeData(
      brightness: Brightness.dark,
      useMaterial3: true,
      fontFamily: 'SfPro',
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      canvasColor: Colors.transparent,
      textSelectionTheme: TextSelectionThemeData(
        cursorColor: AppPalette.cursorDark,
      ),
    );

    return defaultTheme.copyWith(
      textTheme: defaultTheme.textTheme.copyWith(
        // Default text style for Text widget.
        bodyMedium: AppTypography.body1.copyWith(color: Colors.white),
      ),
      extensions: [
        _darkAppColors,
        _darkTextTheme,
      ],
    );
  }();
  static final _darkAppColors = AppColorsExtension(
    primary: AppPalette.primary,
    onPrimary: Colors.black,
    secondary: const Color(0xff03dac6),
    onSecondary: Colors.black,
    error: const Color(0xffcf6679),
    onError: Colors.black,
    background: const Color(0xff121212),
    onBackground: Colors.white,
    surface: const Color(0xff121212),
    onSurface: Colors.white,
    primaryLight: hexToColor('#FFd7DA'),
    white: AppPalette.white,
    barGradient: AppPalette.barGradientDark,
    // Grey
    grey25: AppPalette.grey.grey25Dark,
    grey50: AppPalette.grey.grey50Dark,
    grey100: AppPalette.grey.grey100Dark,
    grey200: AppPalette.grey.grey200Dark,
    grey300: AppPalette.grey.grey300Dark,
    grey400: AppPalette.grey.grey400Dark,
    grey500: AppPalette.grey.grey500Dark,
    grey600: AppPalette.grey.grey600Dark,
    grey700: AppPalette.grey.grey700Dark,
    grey800: AppPalette.grey.grey800Dark,
    grey900: AppPalette.grey.grey900Dark,
    grey950: AppPalette.grey.grey950Dark,
    grey951: AppPalette.grey.grey950,
  );

  static final _darkTextTheme = SimpleAppTextThemeExtension(
    body1: AppTypography.body1.copyWith(color: _darkAppColors.onBackground),
    h1: AppTypography.h1.copyWith(color: Colors.white),
  );
}

extension AppThemeExtension on ThemeData {
  AppColorsExtension get appColors => extension<AppColorsExtension>() ?? AppTheme._lightAppColors;
  SimpleAppTextThemeExtension get appTextTheme => extension<SimpleAppTextThemeExtension>() ?? AppTheme._lightTextTheme;
}

extension ThemeGetter on BuildContext {
  // Usage example: `context.theme`
  ThemeData get theme => Theme.of(this);
}
